# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).


## [Unreleased]

Initial release.

[Unreleased]: https://github.com/fastobo/fastobo-py/compare/77dd00c...HEAD
